@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Log::Any '$log';
 
-our $VERSION = '0.12'; # VERSION
+our $VERSION = '0.13'; # VERSION
 
 use Data::Clean::JSON;
 use Data::Clone;
@@ -97,9 +97,10 @@ _
             description => <<'_',
 
 Code will be called when logging method call. Code will be given a hashref
-argument \%args containing these keys: `args` (arrayref, the original @_),
-`orig` (coderef, the original method), `name` (string, the fully-qualified
-method name), `logger_args` (arguments given when adding logging).
+argument \%args containing these keys: `args` (arrayref, a shallow copy of the
+original @_), `orig` (coderef, the original method), `name` (string, the
+fully-qualified method name), `logger_args` (arguments given when adding
+logging).
 
 You can use this mechanism to customize logging.
 
@@ -122,9 +123,10 @@ _
 
 Just like precall_logger, but code will be called after method is call. Code
 will be given a hashref argument \%args containing these keys: `args` (arrayref,
-the original @_), `orig` (coderef, the original method), `name` (string, the
-fully-qualified method name), `result` (arrayref, the method result),
-`logger_args` (arguments given when adding logging).
+a shallow copy of the original @_), `orig` (coderef, the original method),
+`name` (string, a shallow copy of the fully-qualified method name), `result`
+(arrayref, the method result), `logger_args` (arguments given when adding
+logging).
 
 You can use this mechanism to customize logging.
 
@@ -209,7 +211,7 @@ sub add_logging_to_package {
                 my %largs = (
                     orig   => $sub,
                     name   => $name,
-                    args   => \@_,
+                    args   => [@_],
                     logger_args => $args{logger_args},
                 );
 
@@ -263,7 +265,7 @@ Log::Any::For::Package - Add logging to package
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
@@ -328,9 +330,10 @@ Supply custom postcall logger.
 
 Just like precallI<logger, but code will be called after method is call. Code
 will be given a hashref argument \%args containing these keys: C<args> (arrayref,
-the original @>), C<orig> (coderef, the original method), C<name> (string, the
-fully-qualified method name), C<result> (arrayref, the method result),
-C<logger_args> (arguments given when adding logging).
+a shallow copy of the original @>), C<orig> (coderef, the original method),
+C<name> (string, a shallow copy of the fully-qualified method name), C<result>
+(arrayref, the method result), C<logger_args> (arguments given when adding
+logging).
 
 You can use this mechanism to customize logging.
 
@@ -339,9 +342,10 @@ You can use this mechanism to customize logging.
 Supply custom precall logger.
 
 Code will be called when logging method call. Code will be given a hashref
-argument \%args containing these keys: C<args> (arrayref, the original @_),
-C<orig> (coderef, the original method), C<name> (string, the fully-qualified
-method name), C<logger_args> (arguments given when adding logging).
+argument \%args containing these keys: C<args> (arrayref, a shallow copy of the
+original @_), C<orig> (coderef, the original method), C<name> (string, the
+fully-qualified method name), C<logger_args> (arguments given when adding
+logging).
 
 You can use this mechanism to customize logging.
 
